==> rktSQLite_2.0.05.1.21.zip: rktSQLite2/webapp/modules/browse/manip.php <==
<?php
/* ========================================================================
 - [browse/manip.php]
 - 内容：テーブルの閲覧
 - 作成：高橋 裕志郎
 - ライセンス:
 -      This source file is subject to version 3.0 of the PHP license,
 -      that is available at http://www.php.net/license/3_0.txt
 -      If you did not receive a copy of the PHP license and are unable 
 -      to obtain it through the world-wide-web, please send a note to 
 -      license@php.net so we can mail you a copy immediately.  
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://www.rakuto.net/study/htdocs/
 -      Copyright (C) 2005 `rakuto.net'. All Rights Reserved.
 - 更新履歴：
 -      [2005/01/08] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'rsl_webapp.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends RSL_webapp
{
    /**
     * テーブル名
     * @var string
     */
    private $name = '';

    /**
     * 挙動
     * @var string
     */
    private $action = '';

    /**
     * 確認の為自動クエリを停止
     * @var string
     */
    private $do_query = 0;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    public function execute()
    {
        $this->template_file = 'error.tpl';
        $this->addCss('common.css');

        $this->name = empty($_REQUEST['name'])?'':$_REQUEST['name'];
        $this->action = empty($_REQUEST['action'])?'':$_REQUEST['action'];

        $this->set_type();
        $this->dbinfo->setQuery($this->get_query());
        header("Location: ".$_SERVER['PHP_SELF']."?m=query&do_query=".$this->do_query);
        exit();
    }

    /**
     * テーブルリストの設定
     *
     * @access private
     * @return void
     **/
    private function set_type()
    {
        /* データの取得 */
        $stmt = $this->objdb->prepare("SELECT type FROM sqlite_master WHERE name='".$this->name."'"); 
        $stmt->execute(); 
        $this->type = strToUpper($stmt->fetchSingle());
    }

    /**
     * 生成したクエリの取得
     *
     * @access private
     * @return string
     **/
    private function get_query()
    {        
        switch ($this->action){
        case 'delete':
            $sql = 'DELETE FROM '.$this->name;
            $this->do_query = 0;
            break;
        case 'drop':
            $sql = 'DROP '.$this->type.' '.$this->name;
            $this->do_query = 0;
            break;
        case 'select':
            $sql = 'SELECT * FROM '.$this->name;
            $this->do_query = 1;
            break;
        default:
            break;
        }

        return $sql;
    }
} // webapp
?>

==> rktSQLite2.1.06.zip: rktSQLite2/webapp/modules/browse/manip.php <==
<?php
/* ========================================================================
 - [browse/manip.php]
 - 内容：テーブルの閲覧
 - 作成：高橋 裕志郎
 - ライセンス:
 -      This source file is subject to version 3.0 of the PHP license,
 -      that is available at http://www.php.net/license/3_0.txt
 -      If you did not receive a copy of the PHP license and are unable 
 -      to obtain it through the world-wide-web, please send a note to 
 -      license@php.net so we can mail you a copy immediately.  
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://www.rakuto.net/study/htdocs/
 -      Copyright (C) 2005 `rakuto.net'. All Rights Reserved.
 - 更新履歴：
 -      [2006/03/05] PDO1.0以降に対応
 -      [2005/01/08] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'rsl_webapp.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends RSL_webapp
{
    /**
     * テーブル名
     * @var string
     */
    private $name = '';

    /**
     * 挙動
     * @var string
     */
    private $action = '';

    /**
     * 確認の為自動クエリを停止
     * @var string
     */
    private $do_query = 0;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    public function execute()
    {
        $this->template_file = 'error.tpl';
        $this->addCss('common.css');

        $this->name = empty($_REQUEST['name'])?'':$_REQUEST['name'];
        $this->action = empty($_REQUEST['action'])?'':$_REQUEST['action'];
        $continue = empty($_REQUEST['continue'])?0:1;

        $this->set_type();
        $this->dbinfo->setQuery($this->get_query());
        header("Location: ".$_SERVER['PHP_SELF']."?m=query&do_query=".$this->do_query.'&continue='.$continue);
        exit();
    }

    /**
     * テーブルリストの設定
     *
     * @access private
     * @return void
     **/
    private function set_type()
    {
        /* データの取得 */
        $stmt = $this->objdb->prepare("SELECT type FROM sqlite_master WHERE name='".$this->name."'"); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO::FETCH_ASSOC);
        $this->type = strtoupper($result['type']);
    }

    /**
     * 生成したクエリの取得
     *
     * @access private
     * @return string
     **/
    private function get_query()
    {        
        switch ($this->action){
        case 'delete':
            $sql = 'DELETE FROM '.$this->name;
            $this->do_query = 0;
            break;
        case 'drop':
            $sql = 'DROP '.$this->type.' '.$this->name;
            $this->do_query = 0;
            break;
        case 'select':
            $sql = 'SELECT * FROM '.$this->name;
            $this->do_query = 1;
            break;
        default:
            break;
        }

        return $sql;
    }
} // webapp
?>
